@@ -34,6 +34,10 @@
 #define DEBUG_RCS_YACC		0x08
 #define DEBUG_RCS_FILE		0x10
 
+#define HTMLLEVEL_3		1	/* HTML 3.x compatibility */
+#define HTMLLEVEL_4		2	/* HTML 4.x compatibility */
+#define HTMLLEVEL_X		3	/* XHTML compatibility */
+
 extern int debuglevel;
 
 typedef struct __font_t
@@ -61,12 +65,15 @@ typedef struct __config_t
 	int	transparent_bg;
 	int	box_shadow;
 	int	upside_down;
+	int	left_right;
 	int	strip_untagged;
 	int	strip_first_rev;
 	int	auto_stretch;
 	int	use_ttf;
 	int	anti_alias;
 	int	thick_lines;
+	int	parse_logs;
+	int	html_level;
 
 	font_t	tag_font;
 	color_t	tag_color;
@@ -84,6 +91,13 @@ typedef struct __config_t
 	char	*rev_text;
 	color_t	rev_text_color;
 	font_t	rev_text_font;
+	int	rev_maxtags;
+
+	color_t	merge_color;
+	char	*merge_from;
+	char	*merge_to;
+	int	merge_front;
+	int	merge_nocase;
 
 	font_t	branch_font;
 	color_t	branch_color;
@@ -97,6 +111,8 @@ typedef struct __config_t
 	int	branch_connect;
 	int	branch_margin;
 	int	branch_dupbox;
+	int	branch_fold;
+	int	branch_foldall;
 
 	char	*title;
 	int	title_x;
