@@ -21,6 +21,8 @@
 #ifndef __RCS_H
 #define __RCS_H
 
+struct __revision_t;	/* Forward */
+
 typedef struct __rev_t
 {
 	char	*branch;
@@ -36,8 +38,10 @@ typedef struct __revs_t
 
 typedef struct __tag_t
 {
-	char	*tag;
-	rev_t	*rev;
+	char			*tag;
+	rev_t			*rev;
+	struct __revision_t	*logrev;	/* backpointer to logical revision */
+	int			yofs;		/* Internal drawing offset to center of the tag */
 } tag_t;
 
 typedef struct __tags_t
@@ -46,6 +50,12 @@ typedef struct __tags_t
 	int	ntags;
 } tags_t;
 
+typedef struct __merge_t
+{
+	tag_t	*to;	/* This tag is destination of a merge */
+	tag_t	*from;	/* This tag is origin of a merge */
+} merge_t;
+
 typedef struct __idrev_t
 {
 	char	*id;
@@ -94,19 +104,21 @@ typedef struct __deltas_t
 	int	ndeltas;
 } deltas_t;
 
-struct __revision_t;	/* Forward */
-
 typedef struct __branch_t	/* Logical branch structure */
 {
 	struct __revision_t	**revs;
 	int			nrevs;
 	struct __revision_t	*branchpoint;	/* Backlink to revision that spawned the branch */
-	rev_t			*branch;/* Branch id */
-	tag_t			**tags;	/* Symbolic tags */
+	rev_t			*branch;	/* Branch id */
+	tag_t			**tags;		/* Symbolic tags */
 	int			ntags;
-	int			w, h;	/* BBox width/height */
-	int			cx, y;	/* BBox center-top position */
-	int			tw, th;	/* Total BBox width/height */
+	int			folded;		/* Set if this branch is folded in another box */
+	struct __branch_t	**folds;	/* List of other branches folded into this one */
+	int			nfolds;
+	int			fw;		/* Max width of the branch number if folds present */
+	int			w, h;		/* BBox width/height */
+	int			cx, y;		/* BBox center-top position */
+	int			tw, th;		/* Total BBox width/height */
 } branch_t;
 
 typedef struct __revision_t	/* Logical revision structure */
@@ -152,6 +164,8 @@ typedef struct __rcsfile_t
 	branch_t	**branches;	/* List of branches */
 	branch_t	*active;	/* The active branch (translated branch of admin) */
 	int		nbranches;
+	merge_t		*merges;	/* Merge tags from->to description */
+	int		nmerges;
 	int		tw, th;		/* Total BBox width/height */
 } rcsfile_t;
 
