@@ -96,7 +96,10 @@ static keyword_t keywords[] = {
 	{ "branch_connect",	TYPE_NUMBER,	{ &conf.branch_connect } },
 	{ "branch_margin",	TYPE_NUMBER,	{ &conf.branch_margin } },
 	{ "branch_dupbox",	TYPE_BOOLEAN,	{ &conf.branch_dupbox } },
+	{ "branch_fold",	TYPE_BOOLEAN,	{ &conf.branch_fold } },
+	{ "branch_foldall",	TYPE_BOOLEAN,	{ &conf.branch_foldall } },
 	{ "upside_down",	TYPE_BOOLEAN,	{ &conf.upside_down } },
+	{ "left_right",		TYPE_BOOLEAN,	{ &conf.left_right } },
 	{ "auto_stretch",	TYPE_BOOLEAN,	{ &conf.auto_stretch } },
 	{ "color_bg",		TYPE_COLOR,	{ &conf.color_bg } },
 	{ "transparent_bg",	TYPE_BOOLEAN,	{ &conf.transparent_bg } },
@@ -108,6 +111,8 @@ static keyword_t keywords[] = {
 	{ "strip_first_rev",	TYPE_BOOLEAN,	{ &conf.strip_first_rev } },
 	{ "anti_alias",		TYPE_BOOLEAN,	{ &conf.anti_alias } },
 	{ "use_ttf",		TYPE_BOOLEAN,	{ &conf.use_ttf } },
+	{ "parse_logs",		TYPE_BOOLEAN,	{ &conf.parse_logs } },
+	{ "html_level",		TYPE_NUMBER,	{ &conf.html_level } },
 	{ "thick_lines",	TYPE_NUMBER,	{ &conf.thick_lines } },
 	{ "rev_color",		TYPE_COLOR,	{ &conf.rev_color } },
 	{ "rev_bgcolor",	TYPE_COLOR,	{ &conf.rev_bgcolor } },
@@ -126,6 +131,12 @@ static keyword_t keywords[] = {
 	{ "rev_text_font",	TYPE_FONT,	{ &conf.rev_text_font.gdfont } },
 	{ "rev_text_ttfont",	TYPE_STRING,	{ &conf.rev_text_font.ttfont } },
 	{ "rev_text_ttsize",	TYPE_DOUBLE,	{ &conf.rev_text_font.ttsize } },
+	{ "rev_maxtags",	TYPE_NUMBER,	{ &conf.rev_maxtags } },
+	{ "merge_color",	TYPE_COLOR,	{ &conf.merge_color } },
+	{ "merge_from",		TYPE_STRING,	{ &conf.merge_from } },
+	{ "merge_to",		TYPE_STRING,	{ &conf.merge_to } },
+	{ "merge_front",	TYPE_BOOLEAN,	{ &conf.merge_front } },
+	{ "merge_nocase",	TYPE_BOOLEAN,	{ &conf.merge_nocase } },
 	{ "tag_color",		TYPE_COLOR,	{ &conf.tag_color } },
 	{ "tag_font",		TYPE_FONT,	{ &conf.tag_font.gdfont } },
 	{ "tag_ttfont",		TYPE_STRING,	{ &conf.tag_font.ttfont } },
@@ -165,6 +176,9 @@ static keyword_t keywords[] = {
 	{ "medium",		TYPE_VALUE,	{ (void *)2 } },
 	{ "large",		TYPE_VALUE,	{ (void *)3 } },
 	{ "giant",		TYPE_VALUE,	{ (void *)4 } },
+	{ "HTML3",		TYPE_VALUE,	{ (void *)1 } },
+	{ "HTML4",		TYPE_VALUE,	{ (void *)2 } },
+	{ "XHTML",		TYPE_VALUE,	{ (void *)3 } },
 };
 
 #define NKEYWORDS	(sizeof(keywords) / sizeof(keywords[0]))
@@ -269,6 +283,7 @@ void dump_config(void)
 	debug_pcolor("color_bg", &conf.color_bg);
 	debug_pbool("box_shadow", conf.box_shadow);
 	debug_pbool("upside_down", conf.upside_down);
+	debug_pbool("left_right", conf.left_right);
 	debug_pbool("strip_untagged", conf.strip_untagged);
 	debug_pbool("strip_first_rev", conf.strip_first_rev);
 	debug_pbool("auto_stretch", conf.auto_stretch);
@@ -513,7 +528,7 @@ static int config_lex(void)
 						c[0] = get_input();
 						c[1] = get_input();
 						c[2] = '\0';
-						if(!isxdigit(c[0]) || !isxdigit(c[1]))
+						if(!isxdigit((int)(unsigned char)c[0]) || !isxdigit((int)(unsigned char)c[1]))
 							yyerror("Invalid hex escape");
 						add_str((int)strtol(c, NULL, 16));
 						break;
@@ -564,7 +579,7 @@ static int config_lex(void)
 				while(1)
 				{
 					ch = get_input();
-					if(isalpha(ch) || ch == '_')
+					if(isalnum(ch) || ch == '_')
 						add_str(ch);
 					else
 					{
