@@ -19,19 +19,16 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef __READCONF_H
-#define __READCONF_H
+#ifndef __CVSGRAPH_READCONF_H
+#define __CVSGRAPH_READCONF_H
 
 /* Possible image type outputs. Gif is only supported on old versions of gd */
 #define IMAGE_GIF	0
 #define IMAGE_PNG	1
 #define IMAGE_JPEG	2
 
-
 extern int line_number;
-extern FILE *yyin;
-
-int yylex(void);
-int yyparse(void);
+void stack_option(const char *opt);
+void read_config(const char *path);
 
 #endif
